@@ -5,9 +5,7 @@
 #' A distribution can either have negative skew, no skew or positive skew. A symmetric distribution
 #' will always have no skew but the reverse relationship does not always hold.
 #'
-#' @param skew numeric.
-#'
-#' @seealso \code{\link{skewness}}, \code{\link{exkurtosisType}}
+#' @param skew numeric
 #'
 #' @return Returns one of 'negative skew', 'no skew' or 'positive skew'.
 #'
@@ -17,16 +15,16 @@
 #' skewType(-1)
 #' @export
 skewType <- function(skew) {
-
-  if (is.nan(skew)) {
-    return("undefined")
-  }
-
-  if (skew < 0) {
-    return("negative skew")
-  } else if (skew == 0) {
-    return("no skew")
-  } else {
-    return("positive skew")
-  }
+  vapply(skew,
+         function(.x) {
+           if (is.nan(.x)) {
+             "undefined"
+           } else if (.x < 0) {
+             "negative skew"
+           } else if (.x == 0) {
+             "no skew"
+           } else {
+             "positive skew"
+           }
+         }, character(1))
 }
