@@ -10,4 +10,7 @@ NULL
 #' @importFrom stats setNames
 #' @import set6
 #' @import param6
+#' @import ooplah
 NULL
+
+globalVariables(c("pdf", "cdf"))
